@@ -2,8 +2,8 @@
  * GSysInfo Applet
  *  - A GNOME panel applet to display various system information.
  *  Copyright (C) 2000 Jason D. Hildebrand
- *  - jdhildeb@undergrad.math.uwaterloo.ca
- *  - http://www.undergrad.math.uwaterloo.ca/~jdhildeb/gsysinfo
+ *  - jason@student.math.uwaterloo.ca
+ *  - http://www.student.math.uwaterloo.ca/~jdhildeb/gsysinfo
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -474,42 +474,68 @@ pointer_handler (GtkWidget * w, GdkEvent *event, gpointer data)
     return FALSE;
 } 
 
-void configure_layout( GSysInfoData * gd ) {
-  int cury;
-
-  
-  cury = 0; 
-  if( gd->loadavg_on ) {
-      //gtk_fixed_move( gd->fixed, gd->loadavg_area, 0, cury );
-      gtk_fixed_move( gd->fixed, gd->loadavg_frame, 0, cury );
-      gtk_widget_show( gd->loadavg_frame );
-      cury += gd->bar_depth + gd->gap_depth;
-  } else {
-      gtk_widget_hide( gd->loadavg_frame );
-  }
-  if( gd->load_on ) {
-      gtk_fixed_move( gd->fixed, gd->load_frame, 0, cury );
-      gtk_widget_show( gd->load_frame );
-      cury += gd->bar_depth + gd->gap_depth;
-  } else {
-      gtk_widget_hide( gd->load_frame );
-  }
-  if( gd->mem_on ) {
-      gtk_fixed_move( gd->fixed, gd->mem_frame, 0, cury );
-      gtk_widget_show( gd->mem_frame );
-      cury += gd->bar_depth + gd->gap_depth;
-  } else {
-      gtk_widget_hide( gd->mem_frame );
-  }
-  if( gd->swap_on ) {
-      gtk_fixed_move( gd->fixed, gd->swap_frame, 0, cury );
-      gtk_widget_show( gd->swap_frame );
-      cury += gd->bar_depth + gd->gap_depth;
-  } else {
-      gtk_widget_hide( gd->swap_frame );
-  }
+// the purpose of this function is to determine where 
+// each of the indicators should be placed within the applet,
+// according to the properties
+void next_indicator_placement( GSysInfoData * gd, 
+			       int * numbars, 
+			       int * x, 
+			       int * y )
+{
+    if( *numbars == 0 ) {
+	*x = 0;
+	*y = 0;
+	*numbars += 1;
+    } else if( gd->half_height && *numbars == 2 ) {
+	*x += gd->bar_breadth + 4;
+	*y = 0;
+	*numbars += 1;
+    } else {
+	*y += gd->bar_depth + gd->gap_depth;
+	*numbars += 1;
+    }
 }
 
+
+void configure_layout( GSysInfoData * gd ) {
+    int curx, cury;
+    int numbars;
+  
+    curx = 0; 
+    cury = 0; 
+    numbars = 0;
+
+    if( gd->loadavg_on ) {
+	next_indicator_placement( gd, &numbars, &curx, &cury );
+        gtk_fixed_move( gd->fixed, gd->loadavg_frame, curx, cury );
+        gtk_widget_show( gd->loadavg_frame );
+    } else {
+        gtk_widget_hide( gd->loadavg_frame );
+    }
+    if( gd->load_on ) {
+	next_indicator_placement( gd, &numbars, &curx, &cury );
+        gtk_fixed_move( gd->fixed, gd->load_frame, curx, cury );
+        gtk_widget_show( gd->load_frame );
+    } else {
+        gtk_widget_hide( gd->load_frame );
+    }
+    if( gd->mem_on ) {
+	next_indicator_placement( gd, &numbars, &curx, &cury );
+        gtk_fixed_move( gd->fixed, gd->mem_frame, curx, cury );
+        gtk_widget_show( gd->mem_frame );
+    } else {
+        gtk_widget_hide( gd->mem_frame );
+    }
+    if( gd->swap_on ) {
+	next_indicator_placement( gd, &numbars, &curx, &cury );
+        gtk_fixed_move( gd->fixed, gd->swap_frame, curx, cury );
+        gtk_widget_show( gd->swap_frame );
+    } else {
+        gtk_widget_hide( gd->swap_frame );
+    }
+}
+
+
 GtkWidget *
 applet_start_new_applet (const gchar *goad_id, const char **params,
 			 int nparams)
@@ -520,32 +546,31 @@ applet_start_new_applet (const gchar *goad_id, const char **params,
 /* This is the function that actually creates the display widgets */
 GtkWidget *
 make_new_gsysinfo_applet (const gchar *goad_id) {
-  gchar * param = "gsysinfo_applet";
+    gchar * param = "gsysinfo_applet";
 
-  gd = g_new0 (GSysInfoData, 1);
+    gd = g_new0 (GSysInfoData, 1);
 
-  gd->applet = applet_widget_new (goad_id);
-  gtk_widget_set_usize (gd->applet, gd->bar_breadth, gd->bar_depth * 4 + gd->gap_depth * 4 ); 
+    gd->applet = applet_widget_new (goad_id);
+    gtk_widget_set_usize (gd->applet, 0, 0 ); 
 
-  if (gd->applet == NULL) {
-      return( NULL );
-  }
+    if (gd->applet == NULL) {
+	return( NULL );
+    }
+    gd->setup = FALSE;
 
-  gd->setup = FALSE;
-
-  /*
-   * Load all the saved session parameters (or the defaults if none
-   * exist).
-   */
-  // first load all of the default values
+    /*
+     * Load all the saved session parameters (or the defaults if none
+     * exist).
+     */
+    // first load all of the default values
     gsysinfo_session_defaults (gd);
 
-
     // load values from config file if they exist
     if ( (APPLET_WIDGET (gd->applet)->privcfgpath) && *(APPLET_WIDGET (gd->applet)->privcfgpath)) {
       gsysinfo_session_load (APPLET_WIDGET (gd->applet)->privcfgpath, gd);
     }
 
+
     // create container to hold the bars
     gd->fixed = (GtkFixed *) gtk_fixed_new();
 
@@ -573,11 +598,6 @@ make_new_gsysinfo_applet (const gchar *goad_id) {
     gtk_container_add( GTK_CONTAINER( gd->mem_frame ), gd->mem_area );
     gtk_container_add( GTK_CONTAINER( gd->swap_frame ), gd->swap_area );
 
-    // set sizes of the drawing areas
-    gtk_widget_set_usize (gd->loadavg_area, gd->bar_breadth, gd->bar_depth ); 
-    gtk_widget_set_usize (gd->load_area, gd->bar_breadth, gd->bar_depth );
-    gtk_widget_set_usize (gd->mem_area, gd->bar_breadth, gd->bar_depth );
-    gtk_widget_set_usize (gd->swap_area, gd->bar_breadth, gd->bar_depth );
 
     // place the frames in the fixed container
     //gtk_fixed_put( gd->fixed, gd->loadavg_area, 0, 0 );
@@ -674,7 +694,7 @@ about_cb (AppletWidget *widget, gpointer data)
   GSysInfoData *gd = data;
   char *authors[2];
   
-  authors[0] = "Jason Hildebrand <jdhildeb@undergrad.math.uwaterloo.ca>";
+  authors[0] = "Jason Hildebrand <jdhildeb@student.math.uwaterloo.ca>";
   authors[1] = NULL;
 
   gd->about_box =
@@ -723,36 +743,39 @@ about_cb (AppletWidget *widget, gpointer data)
 void
 gsysinfo_set_size (GSysInfoData * gd)
 {
-  int n;
-
-  gd->numbars = gd->loadavg_on + gd->load_on + gd->mem_on + gd->swap_on;
+    int n;
 
 
-  gd->depth = gd->numbars * gd->bar_depth + ( gd->numbars - 1 ) * gd->gap_depth;
+    // set sizes of the drawing areas
+    gtk_widget_set_usize (gd->loadavg_area, gd->bar_breadth, gd->bar_depth ); 
+    gtk_widget_set_usize (gd->load_area, gd->bar_breadth, gd->bar_depth );
+    gtk_widget_set_usize (gd->mem_area, gd->bar_breadth, gd->bar_depth );
+    gtk_widget_set_usize (gd->swap_area, gd->bar_breadth, gd->bar_depth );
 
-  /*
-   * If pixmaps have already been allocated, then free them here
-   * before creating new ones.  */
-  if (gd->pixmap != NULL) {
-    gdk_pixmap_unref (gd->pixmap);
-  }
+    gd->numbars = gd->loadavg_on + gd->load_on + gd->mem_on + gd->swap_on;
 
-  gd->pixmap = gdk_pixmap_new( gd->loadavg_area->window, 
-			       gd->bar_breadth, 
-			       gd->bar_depth * gd->numbars,
-                               gtk_widget_get_visual (gd->loadavg_area)->depth);
 
-  // clear drawing area
-  gdk_gc_set_foreground (gd->gc, & (AppColors[ BARGAUGEBG ].val) );
-  gdk_draw_rectangle (gd->pixmap, gd->gc, TRUE, 0, 0, gd->bar_breadth, gd->bar_depth * gd->numbars);
+    gd->depth = gd->numbars * gd->bar_depth + ( gd->numbars - 1 ) * gd->gap_depth;
 
-  if (gd->image != NULL) {
-    gdk_image_destroy (gd->image);
-  }
+    /*
+     * If pixmaps have already been allocated, then free them here
+     * before creating new ones.  */
+    if (gd->pixmap != NULL) {
+      gdk_pixmap_unref (gd->pixmap);
+    }
 
-  //for( n = 0; n < gd->numbars; n++ ) {
-      //draw_border( gd, 0, n * gd->bar_depth, gd->bar_breadth - 1, ( n + 1 ) * gd->bar_depth - 1 );
-  //}
+    gd->pixmap = gdk_pixmap_new( gd->loadavg_area->window, 
+			         gd->bar_breadth, 
+			         gd->bar_depth * gd->numbars,
+                                 gtk_widget_get_visual (gd->loadavg_area)->depth);
+
+    // clear drawing area
+    gdk_gc_set_foreground (gd->gc, & (AppColors[ BARGAUGEBG ].val) );
+    gdk_draw_rectangle (gd->pixmap, gd->gc, TRUE, 0, 0, gd->bar_breadth, gd->bar_depth * gd->numbars);
+  
+    if (gd->image != NULL) {
+      gdk_image_destroy (gd->image);
+    }
 
 } /* gsysinfo_set_size */
 
